#[repr(u8)]pub enum Fof0 {
NO_OVERFLOW = 0,
OVERFLOW_DETECTED = 1,
}Variants
NO_OVERFLOW = 0
No result FIFO 0 overflow has occurred since the last time the flag was cleared.
OVERFLOW_DETECTED = 1
At least one result FIFO 0 overflow has occurred since the last time the flag was cleared.
Implementations